Credits
=======

Development Lead
----------------

* Andrea Mucci <andrea@clariteia.com>

Contributors
------------

* Sergio Garcia Prado <sergio.garcia@clariteia.com>
* Vladyslav Fenchak <vladyslav.fenchak@clariteia.com>
